==> tuia-commercial-center-api-0.0.1-20190529.165206-4-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/commercial/mission/config/MissionItemDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.commercial.mission.config;

import cn.com.duiba.tuia.commercial.center.api.dto.commercial.mission.MissionCondition;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.mission.MissionPrize;

import java.io.Serializable;

/**
 * TODO 注释
 *
 * @author zhangbaiqiang
 * @date 2019-04-15
 */
public class MissionItemDto implements Serializable {
    private static final long serialVersionUID = 762160545154327282L;

    private Long itemId;

    private Integer showDay;

    private String picUrl;

    private String prizeDesc;

    private String desc;

    private Long precondition;

    /**
     * 任务条件
     */
    private MissionCondition condition;

    /**
     * 任务奖励
     */
    private MissionPrize prize;

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Integer getShowDay() {
        return showDay;
    }

    public void setShowDay(Integer showDay) {
        this.showDay = showDay;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public String getPrizeDesc() {
        return prizeDesc;
    }

    public void setPrizeDesc(String prizeDesc) {
        this.prizeDesc = prizeDesc;
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    public Long getPrecondition() {
        return precondition;
    }

    public void setPrecondition(Long precondition) {
        this.precondition = precondition;
    }

    public MissionCondition getCondition() {
        return condition;
    }

    public void setCondition(MissionCondition condition) {
        this.condition = condition;
    }

    public MissionPrize getPrize() {
        return prize;
    }

    public void setPrize(MissionPrize prize) {
        this.prize = prize;
    }
}

==> tuia-commercial-center-api-1.1.16-sources.jar: cn/com/duiba/tuia/commercial/center/api/dto/commercial/mission/config/MissionItemDto.java <==
package cn.com.duiba.tuia.commercial.center.api.dto.commercial.mission.config;


import cn.com.duiba.tuia.commercial.center.api.dto.commercial.mission.MissionCondition;
import cn.com.duiba.tuia.commercial.center.api.dto.commercial.mission.MissionPrize;

import java.io.Serializable;

/**
 * TODO 注释
 *
 * @author zhangbaiqiang
 * @date 2019-04-15
 */
public class MissionItemDto implements Serializable {
    private static final long serialVersionUID = 762160545154327282L;

    private Long itemId;

    private Integer showDay;

    private String picUrl;

    private String prizeDesc;

    private String desc;

    private Long precondition;

    /**
     * 任务条件
     */
    private MissionCondition condition;

    /**
     * 开始展示天数
     */
    private Integer startShowDay;


    /**
     * 结束展示天数
     */
    private Integer endShowDay;

    /**
     * 任务奖励
     */
    private MissionPrize prize;

    public Long getItemId() {
        return itemId;
    }

    public void setItemId(Long itemId) {
        this.itemId = itemId;
    }

    public Integer getShowDay() {
        return showDay;
    }

    public void setShowDay(Integer showDay) {
        this.showDay = showDay;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public String getPrizeDesc() {
        return prizeDesc;
    }

    public void setPrizeDesc(String prizeDesc) {
        this.prizeDesc = prizeDesc;
    }

    public String getDesc() {
        return desc;
    }

    public void setDesc(String desc) {
        this.desc = desc;
    }

    public Long getPrecondition() {
        return precondition;
    }

    public void setPrecondition(Long precondition) {
        this.precondition = precondition;
    }

    public MissionCondition getCondition() {
        return condition;
    }

    public void setCondition(MissionCondition condition) {
        this.condition = condition;
    }

    public MissionPrize getPrize() {
        return prize;
    }

    public void setPrize(MissionPrize prize) {
        this.prize = prize;
    }

    public Integer getStartShowDay() {
        return startShowDay;
    }

    public void setStartShowDay(Integer startShowDay) {
        this.startShowDay = startShowDay;
    }

    public Integer getEndShowDay() {
        return endShowDay;
    }

    public void setEndShowDay(Integer endShowDay) {
        this.endShowDay = endShowDay;
    }
}
